/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizaccessrecord.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import jakarta.annotation.Resource;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.biz.modular.bizappointmentrecord.entity.BizAppointmentRecord;
import vip.xiaonuo.biz.modular.bizappointmentrecord.service.BizAppointmentRecordService;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizaccessrecord.entity.BizAccessRecord;
import vip.xiaonuo.biz.modular.bizaccessrecord.mapper.BizAccessRecordMapper;
import vip.xiaonuo.biz.modular.bizaccessrecord.param.BizAccessRecordAddParam;
import vip.xiaonuo.biz.modular.bizaccessrecord.param.BizAccessRecordEditParam;
import vip.xiaonuo.biz.modular.bizaccessrecord.param.BizAccessRecordIdParam;
import vip.xiaonuo.biz.modular.bizaccessrecord.param.BizAccessRecordPageParam;
import vip.xiaonuo.biz.modular.bizaccessrecord.service.BizAccessRecordService;

import java.util.List;

/**
 * 门禁记录表Service接口实现类
 *
 * @author fanzherong
 * @date  2025/03/25 16:48
 **/
@Service
public class BizAccessRecordServiceImpl extends ServiceImpl<BizAccessRecordMapper, BizAccessRecord> implements BizAccessRecordService {

    @Resource
    private BizAppointmentRecordService bizAppointmentRecordService;

    @Override
    public Page<BizAccessRecord> page(BizAccessRecordPageParam bizAccessRecordPageParam) {
        QueryWrapper<BizAccessRecord> queryWrapper = new QueryWrapper<BizAccessRecord>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizAccessRecordPageParam.getLicensePlate())){
            queryWrapper.lambda().like(BizAccessRecord::getLicensePlate,bizAccessRecordPageParam.getLicensePlate());
        }
        if(ObjectUtil.isNotEmpty(bizAccessRecordPageParam.getInOutTimeBegin()) && ObjectUtil.isNotEmpty(bizAccessRecordPageParam.getInOutTimeEnd())){
            queryWrapper.lambda().between(BizAccessRecord::getInOutTime,bizAccessRecordPageParam.getInOutTimeBegin()+ " 00:00:00",
                    bizAccessRecordPageParam.getInOutTimeEnd()+ " 23:59:59");
        }
        queryWrapper.lambda().orderByDesc(BizAccessRecord::getCreateTime);
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizAccessRecordAddParam bizAccessRecordAddParam) {
        //地磅端推送门禁记录
        BizAccessRecord bizAccessRecord = BeanUtil.toBean(bizAccessRecordAddParam, BizAccessRecord.class);
        this.save(bizAccessRecord);

        //修改预约记录状态
        BizAppointmentRecord appointmentRecord = bizAppointmentRecordService.getById(bizAccessRecord.getAppointmentRegisterId());
        if(ObjectUtil.isNotNull(appointmentRecord)){
            if(StringUtils.equals(bizAccessRecord.getInOutFactory(),"1")){
                //进场 待入场->已入场
                appointmentRecord.setStatus("5");
            }else{
                //出场 待出场->已出场
                appointmentRecord.setStatus("10");
            }
        }
        bizAppointmentRecordService.updateById(appointmentRecord);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizAccessRecordEditParam bizAccessRecordEditParam) {
        BizAccessRecord bizAccessRecord = this.queryEntity(bizAccessRecordEditParam.getId());
        BeanUtil.copyProperties(bizAccessRecordEditParam, bizAccessRecord);
        this.updateById(bizAccessRecord);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizAccessRecordIdParam> bizAccessRecordIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizAccessRecordIdParamList, BizAccessRecordIdParam::getId));
    }

    @Override
    public BizAccessRecord detail(BizAccessRecordIdParam bizAccessRecordIdParam) {
        return this.queryEntity(bizAccessRecordIdParam.getId());
    }

    @Override
    public BizAccessRecord queryEntity(String id) {
        BizAccessRecord bizAccessRecord = this.getById(id);
        if(ObjectUtil.isEmpty(bizAccessRecord)) {
            throw new CommonException("门禁记录表不存在，id值为：{}", id);
        }
        return bizAccessRecord;
    }
}
