/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.customer.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import vip.xiaonuo.biz.modular.customer.entity.BizCustomer;
import vip.xiaonuo.biz.modular.customer.param.BizCustomerAddParam;
import vip.xiaonuo.biz.modular.customer.param.BizCustomerEditParam;
import vip.xiaonuo.biz.modular.customer.param.BizCustomerIdParam;
import vip.xiaonuo.biz.modular.customer.param.BizCustomerPageParam;

import java.util.List;
import java.util.Map;
import java.util.Objects;

/**
 * 客户Service接口
 *
 * @author fanzherong
 * @date  2025/03/21 11:44
 **/
public interface BizCustomerService extends IService<BizCustomer> {

    /**
     * 获取客户分页
     *
     * @author fanzherong
     * @date  2025/03/21 11:44
     */
    Page<BizCustomer> page(BizCustomerPageParam bizCustomerPageParam);

    /**
     * 获取有效未删除的列表
     *
     * @author sandy
     * @date  2025/03/28 8:00
     **/
    List<BizCustomer> getList(BizCustomerPageParam bizCustomerPageParam);

    /**
     * 添加客户
     *
     * @author fanzherong
     * @date  2025/03/21 11:44
     */
    void add(BizCustomerAddParam bizCustomerAddParam);

    /**
     * 编辑客户
     *
     * @author fanzherong
     * @date  2025/03/21 11:44
     */
    void edit(BizCustomerEditParam bizCustomerEditParam);

    /**
     * 删除客户
     *
     * @author fanzherong
     * @date  2025/03/21 11:44
     */
    void delete(List<BizCustomerIdParam> bizCustomerIdParamList);

    /**
     * 获取客户详情
     *
     * @author fanzherong
     * @date  2025/03/21 11:44
     */
    BizCustomer detail(BizCustomerIdParam bizCustomerIdParam);

    /**
     * 获取客户详情
     *
     * @author fanzherong
     * @date  2025/03/21 11:44
     **/
    BizCustomer queryEntity(String id);

    /**
     * 获取用友销售订单
     */
    Map<String, Object> getOrderByCustomerId(BizCustomerIdParam bizCustomerIdParam);
}
