/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.officialinfo.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.officialinfo.entity.OfficialInfo;
import vip.xiaonuo.biz.modular.officialinfo.mapper.OfficialInfoMapper;
import vip.xiaonuo.biz.modular.officialinfo.param.OfficialInfoAddParam;
import vip.xiaonuo.biz.modular.officialinfo.param.OfficialInfoEditParam;
import vip.xiaonuo.biz.modular.officialinfo.param.OfficialInfoIdParam;
import vip.xiaonuo.biz.modular.officialinfo.param.OfficialInfoPageParam;
import vip.xiaonuo.biz.modular.officialinfo.service.OfficialInfoService;

import java.util.List;

/**
 * 微信公众号关注表Service接口实现类
 *
 * @author fanzherong
 * @date  2025/04/10 17:31
 **/
@Service
public class OfficialInfoServiceImpl extends ServiceImpl<OfficialInfoMapper, OfficialInfo> implements OfficialInfoService {

    @Override
    public Page<OfficialInfo> page(OfficialInfoPageParam officialInfoPageParam) {
        QueryWrapper<OfficialInfo> queryWrapper = new QueryWrapper<OfficialInfo>().checkSqlInjection();
        if(ObjectUtil.isAllNotEmpty(officialInfoPageParam.getSortField(), officialInfoPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(officialInfoPageParam.getSortOrder());
            queryWrapper.orderBy(true, officialInfoPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(officialInfoPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(OfficialInfo::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(OfficialInfoAddParam officialInfoAddParam) {
        OfficialInfo officialInfo = BeanUtil.toBean(officialInfoAddParam, OfficialInfo.class);
        this.save(officialInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(OfficialInfoEditParam officialInfoEditParam) {
        OfficialInfo officialInfo = this.queryEntity(officialInfoEditParam.getId());
        BeanUtil.copyProperties(officialInfoEditParam, officialInfo);
        this.updateById(officialInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<OfficialInfoIdParam> officialInfoIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(officialInfoIdParamList, OfficialInfoIdParam::getId));
    }

    @Override
    public OfficialInfo detail(OfficialInfoIdParam officialInfoIdParam) {
        return this.queryEntity(officialInfoIdParam.getId());
    }

    @Override
    public OfficialInfo queryEntity(String id) {
        OfficialInfo officialInfo = this.getById(id);
        if(ObjectUtil.isEmpty(officialInfo)) {
            throw new CommonException("微信公众号关注表不存在，id值为：{}", id);
        }
        return officialInfo;
    }
}
