/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.record.result;

import com.alibaba.excel.annotation.ExcelProperty;
import com.alibaba.excel.annotation.format.DateTimeFormat;
import com.alibaba.excel.annotation.write.style.ColumnWidth;
import com.alibaba.excel.annotation.write.style.HeadStyle;
import com.alibaba.excel.enums.BooleanEnum;
import com.alibaba.excel.enums.poi.FillPatternTypeEnum;
import lombok.Getter;
import lombok.Setter;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 人员导出结果集
 *
 * @author xuyuxiang
 * @date 2022/7/8 13:22
 **/
@Getter
@Setter
public class BizRecordExportResult {

    /** 车次编码 */
    @ColumnWidth(20)
    @HeadStyle(fillPatternType = FillPatternTypeEnum.NO_FILL)
    @ExcelProperty({"过磅记录", "车次编码"})
    private String carNumber;

    /** 车牌号码 */
    @HeadStyle(fillPatternType = FillPatternTypeEnum.NO_FILL)
    @ExcelProperty({"过磅记录", "车牌号码"})
    private String licensePlate;

    /** 车牌颜色 */
    @HeadStyle(fillPatternType = FillPatternTypeEnum.NO_FILL)
    @ExcelProperty({"过磅记录", "车牌颜色"})
    private String plateColor;

    /** 毛重 */
    @HeadStyle(fillPatternType = FillPatternTypeEnum.NO_FILL)
    @ExcelProperty({"过磅记录", "称重信息", "毛重（KG）"})
    private BigDecimal grossWeight;

    /** 皮重 */
    @HeadStyle(fillPatternType = FillPatternTypeEnum.NO_FILL)
    @ExcelProperty({"过磅记录", "称重信息", "皮重（KG）"})
    private BigDecimal tareWeight;

    /** 净重 */
    @HeadStyle(fillPatternType = FillPatternTypeEnum.NO_FILL)
    @ExcelProperty({"过磅记录", "称重信息", "净重（KG）"})
    private BigDecimal netWeight;

    /** 过毛时间 */
    @ColumnWidth(30)
    @HeadStyle(fillPatternType = FillPatternTypeEnum.NO_FILL)
    @DateTimeFormat(value = "yyyy-MM-dd HH:mm:ss",use1904windowing = BooleanEnum.TRUE)
    @ExcelProperty({"过磅记录", "称重信息", "过毛时间"})
    private Date grossTime;

    /** 过皮时间 */
    @ColumnWidth(30)
    @HeadStyle(fillPatternType = FillPatternTypeEnum.NO_FILL)
    @DateTimeFormat(value = "yyyy-MM-dd HH:mm:ss",use1904windowing = BooleanEnum.TRUE)
    @ExcelProperty({"过磅记录", "称重信息", "过皮时间"})
    private Date tareTime;


    /** 订单名称 */
    @HeadStyle(fillPatternType = FillPatternTypeEnum.NO_FILL)
    @ExcelProperty({"过磅记录", "订单信息", "订单名称"})
    private String orderName;

    /** 订单编号 */
    @HeadStyle(fillPatternType = FillPatternTypeEnum.NO_FILL)
    @ExcelProperty({"过磅记录", "订单信息", "订单编号"})
    private String orderNumber;

    /** 货品名称 */
    @HeadStyle(fillPatternType = FillPatternTypeEnum.NO_FILL)
    @ExcelProperty({"过磅记录", "货品信息", "货品名称"})
    private String goodsName;

    /** 货品规格 */
    @HeadStyle(fillPatternType = FillPatternTypeEnum.NO_FILL)
    @ExcelProperty({"过磅记录", "货品信息", "货品规格"})
    private String goodsModel;

    /** 收货单位 */
    @ColumnWidth(50)
    @HeadStyle(fillPatternType = FillPatternTypeEnum.NO_FILL)
    @ExcelProperty({"过磅记录", "货品信息", "收货单位"})
    private String receiptCompany;

    /** 发货单位 */
    @ColumnWidth(50)
    @HeadStyle(fillPatternType = FillPatternTypeEnum.NO_FILL)
    @ExcelProperty({"过磅记录", "货品信息", "发货单位"})
    private String shippingCompany;

    /** 运输单位 */
    @ColumnWidth(50)
    @HeadStyle(fillPatternType = FillPatternTypeEnum.NO_FILL)
    @ExcelProperty({"过磅记录", "货品信息", "运输单位"})
    private String transportCompany;

    /** 司机姓名 */
    @HeadStyle(fillPatternType = FillPatternTypeEnum.NO_FILL)
    @ExcelProperty({"过磅记录", "司机信息", "司机姓名"})
    private String driverName;

    /** 司机电话 */
    @HeadStyle(fillPatternType = FillPatternTypeEnum.NO_FILL)
    @ExcelProperty({"过磅记录", "司机信息", "司机电话"})
    private String driverMobile;

    /** 人员状态 */
    @HeadStyle(fillPatternType = FillPatternTypeEnum.NO_FILL)
    @ExcelProperty({"过磅记录", "备注1"})
    private String extKey1;

    /** 人员状态 */
    @HeadStyle(fillPatternType = FillPatternTypeEnum.NO_FILL)
    @ExcelProperty({"过磅记录", "备注2"})
    private String extKey2;
}
